==> markuplint-4.11.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [4.11.0](https://github.com/markuplint/markuplint/compare/markuplint@4.10.1...markuplint@4.11.0) (2024-10-27)


### Bug Fixes

* **markuplint:** remove unnecessary a comma ([dc49a54](https://github.com/markuplint/markuplint/commit/dc49a54359a25ca200edd3928f03ed3ca1f1fe41))


### Features

* **markuplint:** add `--show-config` option to CLI ([a836ddb](https://github.com/markuplint/markuplint/commit/a836ddb50159ec45ac4fc0ced9ca1c66a10c90c1))
* **markuplint:** change `resolveConfig` memthod to public from private ([f3cadb6](https://github.com/markuplint/markuplint/commit/f3cadb630eca4a4a9b754a3cb904ca0e05665110))
* **markuplint:** export `package.json` ([c52a5b9](https://github.com/markuplint/markuplint/commit/c52a5b9afd6c5a2a32e9c46af929c28d9673f501))





## [4.10.1](https://github.com/markuplint/markuplint/compare/markuplint@4.10.0...markuplint@4.10.1) (2024-10-15)

**Note:** Version bump only for package markuplint

# [4.10.0](https://github.com/markuplint/markuplint/compare/markuplint@4.9.4...markuplint@4.10.0) (2024-10-14)

### Features

- **markuplint:** add `--severity-parse-error` option to CLI ([5b9b32f](https://github.com/markuplint/markuplint/commit/5b9b32f99049259cccea41036c4caca92be06805))
- **markuplint:** modified the API to accept `severity.parseError` ([f64a0a1](https://github.com/markuplint/markuplint/commit/f64a0a1d6b03a3731c6d5e83ea27423f96cde49d))

## [4.9.4](https://github.com/markuplint/markuplint/compare/markuplint@4.9.3...markuplint@4.9.4) (2024-09-23)

**Note:** Version bump only for package markuplint

## [4.9.3](https://github.com/markuplint/markuplint/compare/markuplint@4.9.2...markuplint@4.9.3) (2024-09-02)

**Note:** Version bump only for package markuplint

## [4.9.2](https://github.com/markuplint/markuplint/compare/markuplint@4.9.1...markuplint@4.9.2) (2024-06-25)

### Bug Fixes

- **markuplint:** ensure `--config` option correctly handles absolute paths ([fd36c1a](https://github.com/markuplint/markuplint/commit/fd36c1a4475f71d8b1e83212a60639c7361cd702))

## [4.9.1](https://github.com/markuplint/markuplint/compare/markuplint@4.9.0...markuplint@4.9.1) (2024-06-09)

### Bug Fixes

- fix to export type files ([eff4bbf](https://github.com/markuplint/markuplint/commit/eff4bbfd127574809dc5e15d7cafe87699758ee0))

# [4.9.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.1...markuplint@4.9.0) (2024-05-28)

### Features

- **file-resolver:** add `resolve-pretenders` function ([68ba7f5](https://github.com/markuplint/markuplint/commit/68ba7f5acaba13484172bca3ea5f60e0bf3044ef))

## [4.8.1](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0...markuplint@4.8.1) (2024-05-12)

**Note:** Version bump only for package markuplint

# [4.8.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0-alpha.0...markuplint@4.8.0) (2024-05-04)

**Note:** Version bump only for package markuplint

# [4.8.0-alpha.0](https://github.com/markuplint/markuplint/compare/markuplint@4.7.0...markuplint@4.8.0-alpha.0) (2024-05-04)

### Features

- **rules:** apply `no-ambiguous-navigable-target-names` to build-in rules ([93d34f0](https://github.com/markuplint/markuplint/commit/93d34f0ead2624107a5b6f315af0c8bbd4f1e1ec))
- **rules:** apply `table-row-column-alignment` to build-in rules ([85de609](https://github.com/markuplint/markuplint/commit/85de6098813cd7c3167099f9e7e6250ca8324539))

==> markuplint-4.11.1.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [4.11.1](https://github.com/markuplint/markuplint/compare/markuplint@4.11.0...markuplint@4.11.1) (2024-10-28)

**Note:** Version bump only for package markuplint

# [4.11.0](https://github.com/markuplint/markuplint/compare/markuplint@4.10.1...markuplint@4.11.0) (2024-10-27)

### Bug Fixes

- **markuplint:** remove unnecessary a comma ([dc49a54](https://github.com/markuplint/markuplint/commit/dc49a54359a25ca200edd3928f03ed3ca1f1fe41))

### Features

- **markuplint:** add `--show-config` option to CLI ([a836ddb](https://github.com/markuplint/markuplint/commit/a836ddb50159ec45ac4fc0ced9ca1c66a10c90c1))
- **markuplint:** change `resolveConfig` method to public from private ([f3cadb6](https://github.com/markuplint/markuplint/commit/f3cadb630eca4a4a9b754a3cb904ca0e05665110))
- **markuplint:** export `package.json` ([c52a5b9](https://github.com/markuplint/markuplint/commit/c52a5b9afd6c5a2a32e9c46af929c28d9673f501))

## [4.10.1](https://github.com/markuplint/markuplint/compare/markuplint@4.10.0...markuplint@4.10.1) (2024-10-15)

**Note:** Version bump only for package markuplint

# [4.10.0](https://github.com/markuplint/markuplint/compare/markuplint@4.9.4...markuplint@4.10.0) (2024-10-14)

### Features

- **markuplint:** add `--severity-parse-error` option to CLI ([5b9b32f](https://github.com/markuplint/markuplint/commit/5b9b32f99049259cccea41036c4caca92be06805))
- **markuplint:** modified the API to accept `severity.parseError` ([f64a0a1](https://github.com/markuplint/markuplint/commit/f64a0a1d6b03a3731c6d5e83ea27423f96cde49d))

## [4.9.4](https://github.com/markuplint/markuplint/compare/markuplint@4.9.3...markuplint@4.9.4) (2024-09-23)

**Note:** Version bump only for package markuplint

## [4.9.3](https://github.com/markuplint/markuplint/compare/markuplint@4.9.2...markuplint@4.9.3) (2024-09-02)

**Note:** Version bump only for package markuplint

## [4.9.2](https://github.com/markuplint/markuplint/compare/markuplint@4.9.1...markuplint@4.9.2) (2024-06-25)

### Bug Fixes

- **markuplint:** ensure `--config` option correctly handles absolute paths ([fd36c1a](https://github.com/markuplint/markuplint/commit/fd36c1a4475f71d8b1e83212a60639c7361cd702))

## [4.9.1](https://github.com/markuplint/markuplint/compare/markuplint@4.9.0...markuplint@4.9.1) (2024-06-09)

### Bug Fixes

- fix to export type files ([eff4bbf](https://github.com/markuplint/markuplint/commit/eff4bbfd127574809dc5e15d7cafe87699758ee0))

# [4.9.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.1...markuplint@4.9.0) (2024-05-28)

### Features

- **file-resolver:** add `resolve-pretenders` function ([68ba7f5](https://github.com/markuplint/markuplint/commit/68ba7f5acaba13484172bca3ea5f60e0bf3044ef))

## [4.8.1](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0...markuplint@4.8.1) (2024-05-12)

**Note:** Version bump only for package markuplint

# [4.8.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0-alpha.0...markuplint@4.8.0) (2024-05-04)

**Note:** Version bump only for package markuplint

# [4.8.0-alpha.0](https://github.com/markuplint/markuplint/compare/markuplint@4.7.0...markuplint@4.8.0-alpha.0) (2024-05-04)

### Features

- **rules:** apply `no-ambiguous-navigable-target-names` to build-in rules ([93d34f0](https://github.com/markuplint/markuplint/commit/93d34f0ead2624107a5b6f315af0c8bbd4f1e1ec))
- **rules:** apply `table-row-column-alignment` to build-in rules ([85de609](https://github.com/markuplint/markuplint/commit/85de6098813cd7c3167099f9e7e6250ca8324539))
